@@ -35,7 +35,7 @@ class Crawler:
         "Content-Type": "",
         "Cookie": ""
     }
-    def __init__(self,filename,sqlcreate,info,threadnum=1,timeout=20,sleeptime=1,maxtrynum=5):
+    def __init__(self,filename,sqlcreate,info,threadnum=1,timeout=20,sleeptime=1,maxtrynum=5,encoding=''):
         '''
         初始化爬虫配置
         :param url:
@@ -58,6 +58,7 @@ class Crawler:
         self.semphore = threading.Semaphore(self.threadnum)
         self.lockdb = threading.Lock()
         self.locklog = threading.Lock()
+        self.encoding=encoding
         if not os.path.exists("log"):os.mkdir('log')
         if not os.path.exists(f'{self.filename}.db'): self.createsqlite()
 
@@ -153,7 +154,10 @@ class Crawler:
             while not success and trynum<=self.maxtrynum:
                 try:
                     r = requests.get(url, headers=self.getHeaders(), verify=False, timeout=self.timeout)
-                    r.encoding = r.apparent_encoding
+                    if self.encoding=="":
+                        r.encoding = r.apparent_encoding
+                    else:
+                        r.encoding=self.encoding
                     success = True
                     trynum += 1
                 except requests.exceptions.ConnectTimeout as e1:
